##  Uploading File
Only admins have the option to import the transformations via an Excel file in the administration area.
To import transformations in the administration area, do the following:
  1. Navigate to the Transformations section in the Administration area.
  2. Go to the Excel Import & Export tab.
  3. Click Import on the Import Transformation tile.
  4. In the resulting overlay, click either drag and drop the file or browse and upload the file.
  5. Click Import.
